@@ -39,7 +39,7 @@
 
 using namespace KLDAP;
 
-class LdapConfigWidget::Private
+class Q_DECL_HIDDEN LdapConfigWidget::Private
 {
 public:
     Private(LdapConfigWidget *parent)
@@ -101,7 +101,7 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_USER) {
         label = new QLabel(i18n("User:"), mParent);
         mUser = new QLineEdit(mParent);
-        mUser->setObjectName(QLatin1String("kcfg_ldapuser"));
+        mUser->setObjectName(QStringLiteral("kcfg_ldapuser"));
 
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mUser, row, 1, 1, 3);
@@ -111,7 +111,7 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_BINDDN) {
         label = new QLabel(i18n("Bind DN:"), mParent);
         mBindDn = new QLineEdit(mParent);
-        mBindDn->setObjectName(QLatin1String("kcfg_ldapbinddn"));
+        mBindDn->setObjectName(QStringLiteral("kcfg_ldapbinddn"));
 
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mBindDn, row, 1, 1, 3);
@@ -121,7 +121,7 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_REALM) {
         label = new QLabel(i18n("Realm:"), mParent);
         mRealm = new QLineEdit(mParent);
-        mRealm->setObjectName(QLatin1String("kcfg_ldaprealm"));
+        mRealm->setObjectName(QStringLiteral("kcfg_ldaprealm"));
 
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mRealm, row, 1, 1, 3);
@@ -131,7 +131,7 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_PASS) {
         label = new QLabel(i18n("Password:"), mParent);
         mPassword = new QLineEdit(mParent);
-        mPassword->setObjectName(QLatin1String("kcfg_ldappassword"));
+        mPassword->setObjectName(QStringLiteral("kcfg_ldappassword"));
         mPassword->setEchoMode(QLineEdit::Password);
 
         mainLayout->addWidget(label, row, 0);
@@ -142,8 +142,8 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_HOST) {
         label = new QLabel(i18n("Host:"), mParent);
         mHost = new QLineEdit(mParent);
-        mHost->setObjectName(QLatin1String("kcfg_ldaphost"));
-        mParent->connect(mHost, SIGNAL(textChanged(QString)), SIGNAL(hostNameChanged(QString)));
+        mHost->setObjectName(QStringLiteral("kcfg_ldaphost"));
+        mParent->connect(mHost, &QLineEdit::textChanged, mParent, &LdapConfigWidget::hostNameChanged);
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mHost, row, 1, 1, 3);
         row++;
@@ -154,7 +154,7 @@ void LdapConfigWidget::Private::initWidget()
         label = new QLabel(i18n("Port:"), mParent);
         mPort = new QSpinBox(mParent);
         mPort->setRange(0, 65535);
-        mPort->setObjectName(QLatin1String("kcfg_ldapport"));
+        mPort->setObjectName(QStringLiteral("kcfg_ldapport"));
         mPort->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred));
         mPort->setValue(389);
 
@@ -167,7 +167,7 @@ void LdapConfigWidget::Private::initWidget()
         label = new QLabel(i18n("LDAP version:"), mParent);
         mVersion = new QSpinBox(mParent);
         mVersion->setRange(2, 3);
-        mVersion->setObjectName(QLatin1String("kcfg_ldapver"));
+        mVersion->setObjectName(QStringLiteral("kcfg_ldapver"));
         mVersion->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred));
         mVersion->setValue(3);
         mainLayout->addWidget(label, row, col);
@@ -182,7 +182,7 @@ void LdapConfigWidget::Private::initWidget()
         label = new QLabel(i18n("Size limit:"), mParent);
         mSizeLimit = new QSpinBox(mParent);
         mSizeLimit->setRange(0, 9999999);
-        mSizeLimit->setObjectName(QLatin1String("kcfg_ldapsizelimit"));
+        mSizeLimit->setObjectName(QStringLiteral("kcfg_ldapsizelimit"));
         mSizeLimit->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred));
         mSizeLimit->setValue(0);
         mSizeLimit->setSpecialValueText(i18nc("default ldap size limit", "Default"));
@@ -195,7 +195,7 @@ void LdapConfigWidget::Private::initWidget()
         label = new QLabel(i18n("Time limit:"), mParent);
         mTimeLimit = new QSpinBox(mParent);
         mTimeLimit->setRange(0, 9999999);
-        mTimeLimit->setObjectName(QLatin1String("kcfg_ldaptimelimit"));
+        mTimeLimit->setObjectName(QStringLiteral("kcfg_ldaptimelimit"));
         mTimeLimit->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred));
         mTimeLimit->setValue(0);
         mTimeLimit->setSuffix(i18n(" sec"));
@@ -211,7 +211,7 @@ void LdapConfigWidget::Private::initWidget()
         label = new QLabel(i18n("Page size:"), mParent);
         mPageSize = new QSpinBox(mParent);
         mPageSize->setRange(0, 9999999);
-        mPageSize->setObjectName(QLatin1String("kcfg_ldappagesize"));
+        mPageSize->setObjectName(QStringLiteral("kcfg_ldappagesize"));
         mPageSize->setSizePolicy(QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred));
         mPageSize->setValue(0);
         mPageSize->setSpecialValueText(i18n("No paging"));
@@ -222,7 +222,7 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_DN) {
         label = new QLabel(i18nc("Distinguished Name", "DN:"), mParent);
         mDn = new QLineEdit(mParent);
-        mDn->setObjectName(QLatin1String("kcfg_ldapdn"));
+        mDn->setObjectName(QStringLiteral("kcfg_ldapdn"));
 
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mDn, row, 1, 1, 1);
@@ -238,7 +238,7 @@ void LdapConfigWidget::Private::initWidget()
     if (mFeatures & W_FILTER) {
         label = new QLabel(i18n("Filter:"), mParent);
         mFilter = new QLineEdit(mParent);
-        mFilter->setObjectName(QLatin1String("kcfg_ldapfilter"));
+        mFilter->setObjectName(QStringLiteral("kcfg_ldapfilter"));
 
         mainLayout->addWidget(label, row, 0);
         mainLayout->addWidget(mFilter, row, 1, 1, 3);
@@ -250,13 +250,13 @@ void LdapConfigWidget::Private::initWidget()
         QHBoxLayout *hbox = new QHBoxLayout;
         btgroup->setLayout(hbox);
         mSecNo = new QRadioButton(i18nc("@option:radio set no security", "No"), btgroup);
-        mSecNo->setObjectName(QLatin1String("kcfg_ldapnosec"));
+        mSecNo->setObjectName(QStringLiteral("kcfg_ldapnosec"));
         hbox->addWidget(mSecNo);
         mSecTLS = new QRadioButton(i18nc("@option:radio use TLS security", "TLS"), btgroup);
-        mSecTLS->setObjectName(QLatin1String("kcfg_ldaptls"));
+        mSecTLS->setObjectName(QStringLiteral("kcfg_ldaptls"));
         hbox->addWidget(mSecTLS);
         mSecSSL = new QRadioButton(i18nc("@option:radio use SSL security", "SSL"), btgroup);
-        mSecSSL->setObjectName(QLatin1String("kcfg_ldapssl"));
+        mSecSSL->setObjectName(QStringLiteral("kcfg_ldapssl"));
         hbox->addWidget(mSecSSL);
         mainLayout->addWidget(btgroup, row, 0, 1, 4);
 
@@ -279,15 +279,15 @@ void LdapConfigWidget::Private::initWidget()
 
         mAnonymous =
             new QRadioButton(i18nc("@option:radio anonymous authentication", "Anonymous"), authbox);
-        mAnonymous->setObjectName(QLatin1String("kcfg_ldapanon"));
+        mAnonymous->setObjectName(QStringLiteral("kcfg_ldapanon"));
         hbox->addWidget(mAnonymous);
         mSimple =
             new QRadioButton(i18nc("@option:radio simple authentication", "Simple"), authbox);
-        mSimple->setObjectName(QLatin1String("kcfg_ldapsimple"));
+        mSimple->setObjectName(QStringLiteral("kcfg_ldapsimple"));
         hbox->addWidget(mSimple);
         mSASL =
             new QRadioButton(i18nc("@option:radio SASL authentication", "SASL"), authbox);
-        mSASL->setObjectName(QLatin1String("kcfg_ldapsasl"));
+        mSASL->setObjectName(QStringLiteral("kcfg_ldapsasl"));
         hbox->addWidget(mSASL);
 
         hbox = new QHBoxLayout;
@@ -295,11 +295,11 @@ void LdapConfigWidget::Private::initWidget()
         label = new QLabel(i18n("SASL mechanism:"), authbox);
         hbox->addWidget(label);
         mMech = new KComboBox(false, authbox);
-        mMech->setObjectName(QLatin1String("kcfg_ldapsaslmech"));
+        mMech->setObjectName(QStringLiteral("kcfg_ldapsaslmech"));
         mMech->setEditable(true);
-        mMech->addItem(QLatin1String("DIGEST-MD5"));
-        mMech->addItem(QLatin1String("GSSAPI"));
-        mMech->addItem(QLatin1String("PLAIN"));
+        mMech->addItem(QStringLiteral("DIGEST-MD5"));
+        mMech->addItem(QStringLiteral("GSSAPI"));
+        mMech->addItem(QStringLiteral("PLAIN"));
         hbox->addWidget(mMech);
 
         //without host query doesn't make sense
@@ -332,7 +332,7 @@ void LdapConfigWidget::Private::sendQuery()
 
     LdapUrl _url(_server.url());
 
-    _url.setDn(LdapDN(QLatin1String("")));
+    _url.setDn(LdapDN(QStringLiteral("")));
     _url.setAttributes(QStringList(mAttr));
     _url.setScope(LdapUrl::Base);
 
@@ -375,7 +375,7 @@ void LdapConfigWidget::Private::sendQuery()
 
 void LdapConfigWidget::Private::queryMechClicked()
 {
-    mAttr = QLatin1String("supportedsaslmechanisms");
+    mAttr = QStringLiteral("supportedsaslmechanisms");
     sendQuery();
     if (!mQResult.isEmpty()) {
         mQResult.sort();
@@ -386,7 +386,7 @@ void LdapConfigWidget::Private::queryMechClicked()
 
 void LdapConfigWidget::Private::queryDNClicked()
 {
-    mAttr = QLatin1String("namingcontexts");
+    mAttr = QStringLiteral("namingcontexts");
     sendQuery();
     if (!mQResult.isEmpty()) {
         mDn->setText(mQResult.first());
