@@ -24,7 +24,7 @@
 
 using namespace KLDAP;
 
-class Ldif::LdifPrivate
+class Q_DECL_HIDDEN Ldif::LdifPrivate
 {
 public:
     int mModType;
